pub struct AntivirusOverride {
pub action: Option<String>,
pub protocol: Option<String>,
}Expand description
Defines what action to take for antivirus threats per protocol.
This type is not used in any activity, and only used as part of another schema.
Fields
action: Option<String>Required. Threat action override. For some threat types, only a subset of actions applies.
protocol: Option<String>Required. Protocol to match.