pub struct AuthorizationPolicy {
    pub action: Option<String>,
    pub create_time: Option<String>,
    pub description: Option<String>,
    pub labels: Option<HashMap<String, String>>,
    pub name: Option<String>,
    pub rules: Option<Vec<Rule>>,
    pub update_time: Option<String>,
}
AuthorizationPolicy is a resource that specifies how a server should authorize incoming connections. This resource in itself does not change the configuration unless it’s attached to a target https proxy or endpoint config selector resource.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

action: Option<String>

Required. The action to take when a rule match is found. Possible values are “ALLOW” or “DENY”.

create_time: Option<String>

Output only. The timestamp when the resource was created.

description: Option<String>

Optional. Free-text description of the resource.

labels: Option<HashMap<String, String>>

Optional. Set of label tags associated with the AuthorizationPolicy resource.

name: Option<String>

Required. Name of the AuthorizationPolicy resource. It matches pattern projects/{project}/locations/{location}/authorizationPolicies/.

rules: Option<Vec<Rule>>

Optional. List of rules to match. Note that at least one of the rules must match in order for the action specified in the ‘action’ field to be taken. A rule is a match if there is a matching source and destination. If left blank, the action specified in the action field will be applied on every request.

update_time: Option<String>

Output only. The timestamp when the resource was updated.