AuthzPolicy

Struct AuthzPolicy 

pub struct AuthzPolicy {
    pub action: Option<String>,
    pub create_time: Option<DateTime<Utc>>,
    pub custom_provider: Option<AuthzPolicyCustomProvider>,
    pub description: Option<String>,
    pub http_rules: Option<Vec<AuthzPolicyAuthzRule>>,
    pub labels: Option<HashMap<String, String>>,
    pub name: Option<String>,
    pub target: Option<AuthzPolicyTarget>,
    pub update_time: Option<DateTime<Utc>>,
}
AuthzPolicy is a resource that allows to forward traffic to a callout backend designed to scan the traffic for security purposes.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

action: Option<String>

Required. Can be one of ALLOW, DENY, CUSTOM. When the action is CUSTOM, customProvider must be specified. When the action is ALLOW, only requests matching the policy will be allowed. When the action is DENY, only requests matching the policy will be denied. When a request arrives, the policies are evaluated in the following order: 1. If there is a CUSTOM policy that matches the request, the CUSTOM policy is evaluated using the custom authorization providers and the request is denied if the provider rejects the request. 2. If there are any DENY policies that match the request, the request is denied. 3. If there are no ALLOW policies for the resource or if any of the ALLOW policies match the request, the request is allowed. 4. Else the request is denied by default if none of the configured AuthzPolicies with ALLOW action match the request.

create_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was created.

custom_provider: Option<AuthzPolicyCustomProvider>

Optional. Required if the action is CUSTOM. Allows delegating authorization decisions to Cloud IAP or to Service Extensions. One of cloudIap or authzExtension must be specified.

description: Option<String>

Optional. A human-readable description of the resource.

http_rules: Option<Vec<AuthzPolicyAuthzRule>>

Optional. A list of authorization HTTP rules to match against the incoming request. A policy match occurs when at least one HTTP rule matches the request or when no HTTP rules are specified in the policy. At least one HTTP Rule is required for Allow or Deny Action. Limited to 5 rules.

labels: Option<HashMap<String, String>>

Optional. Set of labels associated with the AuthzPolicy resource. The format must comply with the following requirements.

name: Option<String>

Required. Identifier. Name of the AuthzPolicy resource in the following format: projects/{project}/locations/{location}/authzPolicies/{authz_policy}.

target: Option<AuthzPolicyTarget>

Required. Specifies the set of resources to which this policy should be applied to.

update_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was updated.