pub struct AuthzPolicyAuthzRule {
pub from: Option<AuthzPolicyAuthzRuleFrom>,
pub to: Option<AuthzPolicyAuthzRuleTo>,
pub when: Option<String>,
}Expand description
Conditions to match against the incoming request.
This type is not used in any activity, and only used as part of another schema.
Fields
from: Option<AuthzPolicyAuthzRuleFrom>Optional. Describes properties of a source of a request.
to: Option<AuthzPolicyAuthzRuleTo>Optional. Describes properties of a target of a request.
when: Option<String>Optional. CEL expression that describes the conditions to be satisfied for the action. The result of the CEL expression is ANDed with the from and to. Refer to the CEL language reference for a list of available attributes.