pub struct AuthzPolicyAuthzRuleFrom {
pub not_sources: Option<Vec<AuthzPolicyAuthzRuleFromRequestSource>>,
pub sources: Option<Vec<AuthzPolicyAuthzRuleFromRequestSource>>,
}Expand description
Describes properties of one or more sources of a request.
This type is not used in any activity, and only used as part of another schema.
Fields
not_sources: Option<Vec<AuthzPolicyAuthzRuleFromRequestSource>>Optional. Describes the negated properties of request sources. Matches requests from sources that do not match the criteria specified in this field. At least one of sources or notSources must be specified.
sources: Option<Vec<AuthzPolicyAuthzRuleFromRequestSource>>Optional. Describes the properties of a request’s sources. At least one of sources or notSources must be specified. Limited to 1 source. A match occurs when ANY source (in sources or notSources) matches the request. Within a single source, the match follows AND semantics across fields and OR semantics within a single field, i.e. a match occurs when ANY principal matches AND ANY ipBlocks match.