pub struct AuthzPolicyAuthzRuleHeaderMatch {
pub name: Option<String>,
pub value: Option<AuthzPolicyAuthzRuleStringMatch>,
}Expand description
Determines how a HTTP header should be matched.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Optional. Specifies the name of the header in the request.
value: Option<AuthzPolicyAuthzRuleStringMatch>Optional. Specifies how the header match will be performed.