pub struct AuthzPolicyAuthzRulePrincipal {
pub principal: Option<AuthzPolicyAuthzRuleStringMatch>,
pub principal_selector: Option<String>,
}Expand description
Describes the properties of a principal to be matched against.
This type is not used in any activity, and only used as part of another schema.
Fields
principal: Option<AuthzPolicyAuthzRuleStringMatch>Required. A non-empty string whose value is matched against the principal value based on the principal_selector. Only exact match can be applied for CLIENT_CERT_URI_SAN, CLIENT_CERT_DNS_NAME_SAN, CLIENT_CERT_COMMON_NAME selectors.
principal_selector: Option<String>Optional. An enum to decide what principal value the principal rule will match against. If not specified, the PrincipalSelector is CLIENT_CERT_URI_SAN.