pub struct AuthzPolicyAuthzRuleRequestResource {
pub iam_service_account: Option<AuthzPolicyAuthzRuleStringMatch>,
pub tag_value_id_set: Option<AuthzPolicyAuthzRuleRequestResourceTagValueIdSet>,
}Expand description
Describes the properties of a client VM resource accessing the internal application load balancers.
This type is not used in any activity, and only used as part of another schema.
Fields
iam_service_account: Option<AuthzPolicyAuthzRuleStringMatch>Optional. An IAM service account to match against the source service account of the VM sending the request.
tag_value_id_set: Option<AuthzPolicyAuthzRuleRequestResourceTagValueIdSet>Optional. A list of resource tag value permanent IDs to match against the resource manager tags value associated with the source VM of a request.