pub struct AuthzPolicyAuthzRuleRequestResourceTagValueIdSet {
pub ids: Option<Vec<i64>>,
}Expand description
Describes a set of resource tag value permanent IDs to match against the resource manager tags value associated with the source VM of a request.
This type is not used in any activity, and only used as part of another schema.
Fields
ids: Option<Vec<i64>>Required. A list of resource tag value permanent IDs to match against the resource manager tags value associated with the source VM of a request. The match follows AND semantics which means all the ids must match. Limited to 5 ids in the Tag value id set.