pub struct AuthzPolicyAuthzRuleStringMatch {
pub contains: Option<String>,
pub exact: Option<String>,
pub ignore_case: Option<bool>,
pub prefix: Option<String>,
pub suffix: Option<String>,
}Expand description
Determines how a string value should be matched.
This type is not used in any activity, and only used as part of another schema.
Fields
contains: Option<String>The input string must have the substring specified here. Note: empty contains match is not allowed, please use regex instead. Examples: * abc matches the value xyz.abc.def
exact: Option<String>The input string must match exactly the string specified here. Examples: * abc only matches the value abc.
ignore_case: Option<bool>If true, indicates the exact/prefix/suffix/contains matching should be case insensitive. For example, the matcher data will match both input string Data and data if set to true.
prefix: Option<String>The input string must have the prefix specified here. Note: empty prefix is not allowed, please use regex instead. Examples: * abc matches the value abc.xyz
suffix: Option<String>The input string must have the suffix specified here. Note: empty prefix is not allowed, please use regex instead. Examples: * abc matches the value xyz.abc