pub struct AuthzPolicyAuthzRuleTo {
pub not_operations: Option<Vec<AuthzPolicyAuthzRuleToRequestOperation>>,
pub operations: Option<Vec<AuthzPolicyAuthzRuleToRequestOperation>>,
}Expand description
Describes properties of one or more targets of a request.
This type is not used in any activity, and only used as part of another schema.
Fields
not_operations: Option<Vec<AuthzPolicyAuthzRuleToRequestOperation>>Optional. Describes the negated properties of the targets of a request. Matches requests for operations that do not match the criteria specified in this field. At least one of operations or notOperations must be specified.
operations: Option<Vec<AuthzPolicyAuthzRuleToRequestOperation>>Optional. Describes properties of one or more targets of a request. At least one of operations or notOperations must be specified. Limited to 1 operation. A match occurs when ANY operation (in operations or notOperations) matches. Within an operation, the match follows AND semantics across fields and OR semantics within a field, i.e. a match occurs when ANY path matches AND ANY header matches and ANY method matches.