AuthzPolicyAuthzRuleToRequestOperationHeaderSet

Struct AuthzPolicyAuthzRuleToRequestOperationHeaderSet 

pub struct AuthzPolicyAuthzRuleToRequestOperationHeaderSet {
    pub headers: Option<Vec<AuthzPolicyAuthzRuleHeaderMatch>>,
}
Describes a set of HTTP headers to match against.

This type is not used in any activity, and only used as part of another schema.

Fields

headers: Option<Vec<AuthzPolicyAuthzRuleHeaderMatch>>

Required. A list of headers to match against in http header. The match can be one of exact, prefix, suffix, or contains (substring match). The match follows AND semantics which means all the headers must match. Matches are always case sensitive unless the ignoreCase is set. Limited to 10 headers per Authorization Policy.