pub struct AuthzPolicyCustomProvider {
pub authz_extension: Option<AuthzPolicyCustomProviderAuthzExtension>,
pub cloud_iap: Option<AuthzPolicyCustomProviderCloudIap>,
}Expand description
Allows delegating authorization decisions to Cloud IAP or to Service Extensions.
This type is not used in any activity, and only used as part of another schema.
Fields
authz_extension: Option<AuthzPolicyCustomProviderAuthzExtension>Optional. Delegate authorization decision to user authored Service Extension. Only one of cloudIap or authzExtension can be specified.
cloud_iap: Option<AuthzPolicyCustomProviderCloudIap>Optional. Delegates authorization decisions to Cloud IAP. Applicable only for managed load balancers. Enabling Cloud IAP at the AuthzPolicy level is not compatible with Cloud IAP settings in the BackendService. Enabling IAP in both places will result in request failure. Ensure that IAP is enabled in either the AuthzPolicy or the BackendService but not in both places.