pub struct AuthzPolicyCustomProviderAuthzExtension {
pub resources: Option<Vec<String>>,
}Expand description
Optional. Delegate authorization decision to user authored extension. Only one of cloudIap or authzExtension can be specified.
This type is not used in any activity, and only used as part of another schema.
Fields
resources: Option<Vec<String>>Required. A list of references to authorization extensions that will be invoked for requests matching this policy. Limited to 1 custom provider.