pub struct AuthzPolicyCustomProviderCloudIap { /* private fields */ }Expand description
Optional. Delegates authorization decisions to Cloud IAP. Applicable only for managed load balancers. Enabling Cloud IAP at the AuthzPolicy level is not compatible with Cloud IAP settings in the BackendService. Enabling IAP in both places will result in request failure. Ensure that IAP is enabled in either the AuthzPolicy or the BackendService but not in both places.
This type is not used in any activity, and only used as part of another schema.