BackendAuthenticationConfig

Struct BackendAuthenticationConfig 

pub struct BackendAuthenticationConfig {
    pub client_certificate: Option<String>,
    pub create_time: Option<DateTime<Utc>>,
    pub description: Option<String>,
    pub etag: Option<String>,
    pub labels: Option<HashMap<String, String>>,
    pub name: Option<String>,
    pub trust_config: Option<String>,
    pub update_time: Option<DateTime<Utc>>,
    pub well_known_roots: Option<String>,
}
BackendAuthenticationConfig message groups the TrustConfig together with other settings that control how the load balancer authenticates, and expresses its identity to, the backend: * trustConfig is the attached TrustConfig. * wellKnownRoots indicates whether the load balance should trust backend server certificates that are issued by public certificate authorities, in addition to certificates trusted by the TrustConfig. * clientCertificate is a client certificate that the load balancer uses to express its identity to the backend, if the connection to the backend uses mTLS. You can attach the BackendAuthenticationConfig to the load balancer’s BackendService directly determining how that BackendService negotiates TLS.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

client_certificate: Option<String>

Optional. A reference to a certificatemanager.googleapis.com.Certificate resource. This is a relative resource path following the form “projects/{project}/locations/{location}/certificates/{certificate}”. Used by a BackendService to negotiate mTLS when the backend connection uses TLS and the backend requests a client certificate. Must have a CLIENT_AUTH scope.

create_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was created.

description: Option<String>

Optional. Free-text description of the resource.

etag: Option<String>

Output only. Etag of the resource.

labels: Option<HashMap<String, String>>

Set of label tags associated with the resource.

name: Option<String>

Required. Name of the BackendAuthenticationConfig resource. It matches the pattern projects/*/locations/{location}/backendAuthenticationConfigs/{backend_authentication_config}

trust_config: Option<String>

Optional. A reference to a TrustConfig resource from the certificatemanager.googleapis.com namespace. This is a relative resource path following the form “projects/{project}/locations/{location}/trustConfigs/{trust_config}”. A BackendService uses the chain of trust represented by this TrustConfig, if specified, to validate the server certificates presented by the backend. Required unless wellKnownRoots is set to PUBLIC_ROOTS.

update_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was updated.

well_known_roots: Option<String>

Well known roots to use for server certificate validation.