pub struct CustomInterceptProfile {
pub intercept_endpoint_group: Option<String>,
}Expand description
CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
This type is not used in any activity, and only used as part of another schema.
Fields
intercept_endpoint_group: Option<String>Required. The target InterceptEndpointGroup. When a firewall rule with this security profile attached matches a packet, the packet will be intercepted to the location-local target in this group.