pub struct CustomMirroringProfile {
pub mirroring_endpoint_group: Option<String>,
}Expand description
CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action.
This type is not used in any activity, and only used as part of another schema.
Fields
mirroring_endpoint_group: Option<String>Required. Immutable. The target MirroringEndpointGroup. When a mirroring rule with this security profile attached matches a packet, a replica will be mirrored to the location-local target in this group.