pub struct FirewallEndpoint {Show 13 fields
pub associated_networks: Option<Vec<String>>,
pub associations: Option<Vec<FirewallEndpointAssociationReference>>,
pub billing_project_id: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub endpoint_settings: Option<FirewallEndpointEndpointSettings>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub reconciling: Option<bool>,
pub satisfies_pzi: Option<bool>,
pub satisfies_pzs: Option<bool>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
Message describing Endpoint object.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations firewall endpoints create organizations (request)
- locations firewall endpoints get organizations (response)
- locations firewall endpoints patch organizations (request)
- locations firewall endpoints create projects (request)
- locations firewall endpoints get projects (response)
- locations firewall endpoints patch projects (request)
Fields
associated_networks: Option<Vec<String>>Output only. List of networks that are associated with this endpoint in the local zone. This is a projection of the FirewallEndpointAssociations pointing at this endpoint. A network will only appear in this list after traffic routing is fully configured. Format: projects/{project}/global/networks/{name}.
associations: Option<Vec<FirewallEndpointAssociationReference>>Output only. List of FirewallEndpointAssociations that are associated to this endpoint. An association will only appear in this list after traffic routing is fully configured.
billing_project_id: Option<String>Required. Project to bill on endpoint uptime usage.
create_time: Option<DateTime<Utc>>Output only. Create time stamp.
description: Option<String>Optional. Description of the firewall endpoint. Max length 2048 characters.
endpoint_settings: Option<FirewallEndpointEndpointSettings>Optional. Settings for the endpoint.
labels: Option<HashMap<String, String>>Optional. Labels as key value pairs
name: Option<String>Immutable. Identifier. Name of resource.
reconciling: Option<bool>Output only. Whether reconciling is in progress, recommended per https://google.aip.dev/128.
satisfies_pzi: Option<bool>Output only. [Output Only] Reserved for future use.
satisfies_pzs: Option<bool>Output only. [Output Only] Reserved for future use.
state: Option<String>Output only. Current state of the endpoint.
update_time: Option<DateTime<Utc>>Output only. Update time stamp