pub struct FirewallEndpointAssociation {
pub create_time: Option<DateTime<Utc>>,
pub disabled: Option<bool>,
pub firewall_endpoint: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub network: Option<String>,
pub reconciling: Option<bool>,
pub state: Option<String>,
pub tls_inspection_policy: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
Message describing Association object
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
create_time: Option<DateTime<Utc>>Output only. Create time stamp
disabled: Option<bool>Optional. Whether the association is disabled. True indicates that traffic won’t be intercepted
firewall_endpoint: Option<String>Required. The URL of the FirewallEndpoint that is being associated.
labels: Option<HashMap<String, String>>Optional. Labels as key value pairs
name: Option<String>Immutable. Identifier. name of resource
network: Option<String>Required. The URL of the network that is being associated.
reconciling: Option<bool>Output only. Whether reconciling is in progress, recommended per https://google.aip.dev/128.
state: Option<String>Output only. Current state of the association.
tls_inspection_policy: Option<String>Optional. The URL of the TlsInspectionPolicy that is being associated.
update_time: Option<DateTime<Utc>>Output only. Update time stamp