pub struct GatewaySecurityPolicy {
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub name: Option<String>,
pub tls_inspection_policy: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
The GatewaySecurityPolicy resource contains a collection of GatewaySecurityPolicyRules and associated metadata.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
create_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was created.
description: Option<String>Optional. Free-text description of the resource.
name: Option<String>Required. Name of the resource. Name is of the form projects/{project}/locations/{location}/gatewaySecurityPolicies/{gateway_security_policy} gateway_security_policy should match the pattern:(^a-z?$).
tls_inspection_policy: Option<String>Optional. Name of a TLS Inspection Policy resource that defines how TLS inspection will be performed for any rule(s) which enables it.
update_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was updated.