pub struct GatewaySecurityPolicyRule {
pub application_matcher: Option<String>,
pub basic_profile: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub enabled: Option<bool>,
pub name: Option<String>,
pub priority: Option<i32>,
pub session_matcher: Option<String>,
pub tls_inspection_enabled: Option<bool>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
The GatewaySecurityPolicyRule resource is in a nested collection within a GatewaySecurityPolicy and represents a traffic matching condition and associated action to perform.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
application_matcher: Option<String>Optional. CEL expression for matching on L7/application level criteria.
basic_profile: Option<String>Required. Profile which tells what the primitive action should be.
create_time: Option<DateTime<Utc>>Output only. Time when the rule was created.
description: Option<String>Optional. Free-text description of the resource.
enabled: Option<bool>Required. Whether the rule is enforced.
name: Option<String>Required. Immutable. Name of the resource. ame is the full resource name so projects/{project}/locations/{location}/gatewaySecurityPolicies/{gateway_security_policy}/rules/{rule} rule should match the pattern: (^a-z?$).
priority: Option<i32>Required. Priority of the rule. Lower number corresponds to higher precedence.
session_matcher: Option<String>Required. CEL expression for matching on session criteria.
tls_inspection_enabled: Option<bool>Optional. Flag to enable TLS inspection of traffic matching on , can only be true if the parent GatewaySecurityPolicy references a TLSInspectionConfig.
update_time: Option<DateTime<Utc>>Output only. Time when the rule was updated.