pub struct GoogleCloudNetworksecurityV1CertificateProvider {
pub certificate_provider_instance: Option<CertificateProviderInstance>,
pub grpc_endpoint: Option<GoogleCloudNetworksecurityV1GrpcEndpoint>,
}Expand description
Specification of certificate provider. Defines the mechanism to obtain the certificate and private key for peer to peer authentication.
This type is not used in any activity, and only used as part of another schema.
Fields
certificate_provider_instance: Option<CertificateProviderInstance>The certificate provider instance specification that will be passed to the data plane, which will be used to load necessary credential information.
grpc_endpoint: Option<GoogleCloudNetworksecurityV1GrpcEndpoint>gRPC specific configuration to access the gRPC server to obtain the cert and private key.