pub struct GoogleCloudNetworksecurityV1GrpcEndpoint {
pub target_uri: Option<String>,
}Expand description
Specification of the GRPC Endpoint.
This type is not used in any activity, and only used as part of another schema.
Fields
target_uri: Option<String>Required. The target URI of the gRPC endpoint. Only UDS path is supported, and should start with “unix:”.