pub struct HttpHeaderMatch {
    pub header_name: Option<String>,
    pub regex_match: Option<String>,
}
Specification of HTTP header match atrributes.

This type is not used in any activity, and only used as part of another schema.

Fields

header_name: Option<String>

Required. The name of the HTTP header to match. For matching against the HTTP request’s authority, use a headerMatch with the header name “:authority”. For matching a request’s method, use the headerName “:method”.

regex_match: Option<String>

Required. The value of the header must match the regular expression specified in regexMatch. For regular expression grammar, please see: en.cppreference.com/w/cpp/regex/ecmascript For matching against a port specified in the HTTP request, use a headerMatch with headerName set to Host and a regular expression that satisfies the RFC2616 Host header’s port specifier.