pub struct InterceptDeploymentGroupDeployment {
pub name: Option<String>,
pub state: Option<String>,
}Expand description
A deployment belonging to this deployment group.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Output only. The name of the Intercept Deployment, in the format: projects/{project}/locations/{location}/interceptDeployments/{intercept_deployment}.
state: Option<String>Output only. Most recent known state of the deployment.