InterceptEndpointGroupAssociation

Struct InterceptEndpointGroupAssociation 

pub struct InterceptEndpointGroupAssociation {
    pub create_time: Option<DateTime<Utc>>,
    pub intercept_endpoint_group: Option<String>,
    pub labels: Option<HashMap<String, String>>,
    pub locations: Option<Vec<InterceptLocation>>,
    pub locations_details: Option<Vec<InterceptEndpointGroupAssociationLocationDetails>>,
    pub name: Option<String>,
    pub network: Option<String>,
    pub reconciling: Option<bool>,
    pub state: Option<String>,
    pub update_time: Option<DateTime<Utc>>,
}
An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable intercept by itself. To enable intercept, the user must also create a network firewall policy containing intercept rules and associate it with the network.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

create_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

intercept_endpoint_group: Option<String>

Required. Immutable. The endpoint group that this association is connected to, for example: projects/123456789/locations/global/interceptEndpointGroups/my-eg. See https://google.aip.dev/124.

labels: Option<HashMap<String, String>>

Optional. Labels are key/value pairs that help to organize and filter resources.

locations: Option<Vec<InterceptLocation>>

Output only. The list of locations where the association is configured. This information is retrieved from the linked endpoint group.

locations_details: Option<Vec<InterceptEndpointGroupAssociationLocationDetails>>

Output only. The list of locations where the association is present. This information is retrieved from the linked endpoint group, and not configured as part of the association itself.

name: Option<String>

Immutable. Identifier. The resource name of this endpoint group association, for example: projects/123456789/locations/global/interceptEndpointGroupAssociations/my-eg-association. See https://google.aip.dev/122 for more details.

network: Option<String>

Required. Immutable. The VPC network that is associated. for example: projects/123456789/global/networks/my-network. See https://google.aip.dev/124.

reconciling: Option<bool>

Output only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This part of the normal operation (e.g. adding a new location to the target deployment group). See https://google.aip.dev/128.

state: Option<String>

Output only. Current state of the endpoint group association.

update_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.