pub struct InterceptEndpointGroupAssociationLocationDetails {
pub location: Option<String>,
pub state: Option<String>,
}Expand description
Contains details about the state of an association in a specific cloud location.
This type is not used in any activity, and only used as part of another schema.
Fields
location: Option<String>Output only. The cloud location, e.g. “us-central1-a” or “asia-south1”.
state: Option<String>Output only. The current state of the association in this location.