pub struct ListAuthzPoliciesResponse {
pub authz_policies: Option<Vec<AuthzPolicy>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
Message for response to listing AuthzPolicy resources.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations authz policies list projects (response)
Fields
authz_policies: Option<Vec<AuthzPolicy>>The list of AuthzPolicy resources.
next_page_token: Option<String>A token identifying a page of results that the server returns.
unreachable: Option<Vec<String>>Locations that could not be reached.