pub struct ListBackendAuthenticationConfigsResponse {
pub backend_authentication_configs: Option<Vec<BackendAuthenticationConfig>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
Response returned by the ListBackendAuthenticationConfigs method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
backend_authentication_configs: Option<Vec<BackendAuthenticationConfig>>List of BackendAuthenticationConfig resources.
next_page_token: Option<String>If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token.
unreachable: Option<Vec<String>>Locations that could not be reached.