pub struct ListDnsThreatDetectorsResponse {
pub dns_threat_detectors: Option<Vec<DnsThreatDetector>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response message to requesting a list of DnsThreatDetectors.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations dns threat detectors list projects (response)
Fields
dns_threat_detectors: Option<Vec<DnsThreatDetector>>The list of DnsThreatDetector resources.
next_page_token: Option<String>A token, which can be sent as page_token, to retrieve the next page.
unreachable: Option<Vec<String>>Unordered list. Unreachable DnsThreatDetector resources.