pub struct ListInterceptEndpointGroupAssociationsResponse {
pub intercept_endpoint_group_associations: Option<Vec<InterceptEndpointGroupAssociation>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListInterceptEndpointGroupAssociations.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
intercept_endpoint_group_associations: Option<Vec<InterceptEndpointGroupAssociation>>The associations from the specified parent.
next_page_token: Option<String>A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.