pub struct ListMirroringEndpointGroupsResponse {
pub mirroring_endpoint_groups: Option<Vec<MirroringEndpointGroup>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListMirroringEndpointGroups.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
mirroring_endpoint_groups: Option<Vec<MirroringEndpointGroup>>The endpoint groups from the specified parent.
next_page_token: Option<String>A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. See https://google.aip.dev/158 for more details.