pub struct ListServerTlsPoliciesResponse {
pub next_page_token: Option<String>,
pub server_tls_policies: Option<Vec<ServerTlsPolicy>>,
}Expand description
Response returned by the ListServerTlsPolicies method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations server tls policies list projects (response)
Fields
next_page_token: Option<String>If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token.
server_tls_policies: Option<Vec<ServerTlsPolicy>>List of ServerTlsPolicy resources.