Struct google_networksecurity1::api::MTLSPolicy
source · [−]pub struct MTLSPolicy {
pub client_validation_ca: Option<Vec<ValidationCA>>,
}Expand description
Specification of the MTLSPolicy.
This type is not used in any activity, and only used as part of another schema.
Fields
client_validation_ca: Option<Vec<ValidationCA>>Defines the mechanism to obtain the Certificate Authority certificate to validate the client certificate.