MirroringDeploymentGroup

Struct MirroringDeploymentGroup 

pub struct MirroringDeploymentGroup {
    pub connected_endpoint_groups: Option<Vec<MirroringDeploymentGroupConnectedEndpointGroup>>,
    pub create_time: Option<DateTime<Utc>>,
    pub description: Option<String>,
    pub labels: Option<HashMap<String, String>>,
    pub locations: Option<Vec<MirroringLocation>>,
    pub name: Option<String>,
    pub nested_deployments: Option<Vec<MirroringDeploymentGroupDeployment>>,
    pub network: Option<String>,
    pub reconciling: Option<bool>,
    pub state: Option<String>,
    pub update_time: Option<DateTime<Utc>>,
}
A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

connected_endpoint_groups: Option<Vec<MirroringDeploymentGroupConnectedEndpointGroup>>

Output only. The list of endpoint groups that are connected to this resource.

create_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.

description: Option<String>

Optional. User-provided description of the deployment group. Used as additional context for the deployment group.

labels: Option<HashMap<String, String>>

Optional. Labels are key/value pairs that help to organize and filter resources.

locations: Option<Vec<MirroringLocation>>

Output only. The list of locations where the deployment group is present.

name: Option<String>

Immutable. Identifier. The resource name of this deployment group, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/122 for more details.

nested_deployments: Option<Vec<MirroringDeploymentGroupDeployment>>

Output only. The list of Mirroring Deployments that belong to this group.

network: Option<String>

Required. Immutable. The network that will be used for all child deployments, for example: projects/{project}/global/networks/{network}. See https://google.aip.dev/124.

reconciling: Option<bool>

Output only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https://google.aip.dev/128.

state: Option<String>

Output only. The current state of the deployment group. See https://google.aip.dev/216.

update_time: Option<DateTime<Utc>>

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.