pub struct MirroringEndpointGroupConnectedDeploymentGroup {
pub locations: Option<Vec<MirroringLocation>>,
pub name: Option<String>,
}Expand description
The endpoint group’s view of a connected deployment group.
This type is not used in any activity, and only used as part of another schema.
Fields
locations: Option<Vec<MirroringLocation>>Output only. The list of locations where the deployment group is present.
name: Option<String>Output only. The connected deployment group’s resource name, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.