pub struct Operation {
pub done: Option<bool>,
pub error: Option<Status>,
pub metadata: Option<HashMap<String, Value>>,
pub name: Option<String>,
pub response: Option<HashMap<String, Value>>,
}Expand description
This resource represents a long-running operation that is the result of a network API call.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations address groups add items organizations (response)
- locations address groups clone items organizations (response)
- locations address groups create organizations (response)
- locations address groups delete organizations (response)
- locations address groups patch organizations (response)
- locations address groups remove items organizations (response)
- locations firewall endpoints create organizations (response)
- locations firewall endpoints delete organizations (response)
- locations firewall endpoints patch organizations (response)
- locations operations get organizations (response)
- locations security profile groups create organizations (response)
- locations security profile groups delete organizations (response)
- locations security profile groups patch organizations (response)
- locations security profiles create organizations (response)
- locations security profiles delete organizations (response)
- locations security profiles patch organizations (response)
- locations address groups add items projects (response)
- locations address groups clone items projects (response)
- locations address groups create projects (response)
- locations address groups delete projects (response)
- locations address groups patch projects (response)
- locations address groups remove items projects (response)
- locations authorization policies create projects (response)
- locations authorization policies delete projects (response)
- locations authorization policies patch projects (response)
- locations authz policies create projects (response)
- locations authz policies delete projects (response)
- locations authz policies patch projects (response)
- locations backend authentication configs create projects (response)
- locations backend authentication configs delete projects (response)
- locations backend authentication configs patch projects (response)
- locations client tls policies create projects (response)
- locations client tls policies delete projects (response)
- locations client tls policies patch projects (response)
- locations firewall endpoint associations create projects (response)
- locations firewall endpoint associations delete projects (response)
- locations firewall endpoint associations patch projects (response)
- locations firewall endpoints create projects (response)
- locations firewall endpoints delete projects (response)
- locations firewall endpoints patch projects (response)
- locations gateway security policies rules create projects (response)
- locations gateway security policies rules delete projects (response)
- locations gateway security policies rules patch projects (response)
- locations gateway security policies create projects (response)
- locations gateway security policies delete projects (response)
- locations gateway security policies patch projects (response)
- locations intercept deployment groups create projects (response)
- locations intercept deployment groups delete projects (response)
- locations intercept deployment groups patch projects (response)
- locations intercept deployments create projects (response)
- locations intercept deployments delete projects (response)
- locations intercept deployments patch projects (response)
- locations intercept endpoint group associations create projects (response)
- locations intercept endpoint group associations delete projects (response)
- locations intercept endpoint group associations patch projects (response)
- locations intercept endpoint groups create projects (response)
- locations intercept endpoint groups delete projects (response)
- locations intercept endpoint groups patch projects (response)
- locations mirroring deployment groups create projects (response)
- locations mirroring deployment groups delete projects (response)
- locations mirroring deployment groups patch projects (response)
- locations mirroring deployments create projects (response)
- locations mirroring deployments delete projects (response)
- locations mirroring deployments patch projects (response)
- locations mirroring endpoint group associations create projects (response)
- locations mirroring endpoint group associations delete projects (response)
- locations mirroring endpoint group associations patch projects (response)
- locations mirroring endpoint groups create projects (response)
- locations mirroring endpoint groups delete projects (response)
- locations mirroring endpoint groups patch projects (response)
- locations operations get projects (response)
- locations server tls policies create projects (response)
- locations server tls policies delete projects (response)
- locations server tls policies patch projects (response)
- locations tls inspection policies create projects (response)
- locations tls inspection policies delete projects (response)
- locations tls inspection policies patch projects (response)
- locations url lists create projects (response)
- locations url lists delete projects (response)
- locations url lists patch projects (response)
Fields
done: Option<bool>If the value is false, it means the operation is still in progress. If true, the operation is completed, and either error or response is available.
error: Option<Status>The error result of the operation in case of failure or cancellation.
metadata: Option<HashMap<String, Value>>Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any.
name: Option<String>The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/{unique_id}.
response: Option<HashMap<String, Value>>The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf.Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse.