pub struct Rule {
    pub destinations: Option<Vec<Destination>>,
    pub sources: Option<Vec<Source>>,
}
Specification of rules.

This type is not used in any activity, and only used as part of another schema.

Fields

destinations: Option<Vec<Destination>>

Optional. List of attributes for the traffic destination. All of the destinations must match. A destination is a match if a request matches all the specified hosts, ports, methods and headers. If not set, the action specified in the ‘action’ field will be applied without any rule checks for the destination.

sources: Option<Vec<Source>>

Optional. List of attributes for the traffic source. All of the sources must match. A source is a match if both principals and ip_blocks match. If not set, the action specified in the ‘action’ field will be applied without any rule checks for the source.