pub struct SecurityProfile {
pub create_time: Option<DateTime<Utc>>,
pub custom_intercept_profile: Option<CustomInterceptProfile>,
pub custom_mirroring_profile: Option<CustomMirroringProfile>,
pub description: Option<String>,
pub etag: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub threat_prevention_profile: Option<ThreatPreventionProfile>,
pub type_: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
create_time: Option<DateTime<Utc>>Output only. Resource creation timestamp.
custom_intercept_profile: Option<CustomInterceptProfile>The custom TPPI configuration for the SecurityProfile.
custom_mirroring_profile: Option<CustomMirroringProfile>The custom Packet Mirroring v2 configuration for the SecurityProfile.
description: Option<String>Optional. An optional description of the profile. Max length 512 characters.
etag: Option<String>Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
labels: Option<HashMap<String, String>>Optional. Labels as key value pairs.
name: Option<String>Immutable. Identifier. Name of the SecurityProfile resource. It matches pattern projects|organizations/*/locations/{location}/securityProfiles/{security_profile}.
threat_prevention_profile: Option<ThreatPreventionProfile>The threat prevention configuration for the SecurityProfile.
type_: Option<String>Immutable. The single ProfileType that the SecurityProfile resource configures.
update_time: Option<DateTime<Utc>>Output only. Last resource update timestamp.