pub struct SecurityProfileGroup {
pub create_time: Option<DateTime<Utc>>,
pub custom_intercept_profile: Option<String>,
pub custom_mirroring_profile: Option<String>,
pub data_path_id: Option<u64>,
pub description: Option<String>,
pub etag: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub threat_prevention_profile: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
create_time: Option<DateTime<Utc>>Output only. Resource creation timestamp.
custom_intercept_profile: Option<String>Optional. Reference to a SecurityProfile with the CustomIntercept configuration.
custom_mirroring_profile: Option<String>Optional. Reference to a SecurityProfile with the CustomMirroring configuration.
data_path_id: Option<u64>Output only. Identifier used by the data-path. Unique within {container, location}.
description: Option<String>Optional. An optional description of the profile group. Max length 2048 characters.
etag: Option<String>Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
labels: Option<HashMap<String, String>>Optional. Labels as key value pairs.
name: Option<String>Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches pattern projects|organizations/*/locations/{location}/securityProfileGroups/{security_profile_group}.
threat_prevention_profile: Option<String>Optional. Reference to a SecurityProfile with the ThreatPrevention configuration.
update_time: Option<DateTime<Utc>>Output only. Last resource update timestamp.