ThreatPreventionProfile

Struct ThreatPreventionProfile 

pub struct ThreatPreventionProfile {
    pub antivirus_overrides: Option<Vec<AntivirusOverride>>,
    pub severity_overrides: Option<Vec<SeverityOverride>>,
    pub threat_overrides: Option<Vec<ThreatOverride>>,
}
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.

This type is not used in any activity, and only used as part of another schema.

Fields

antivirus_overrides: Option<Vec<AntivirusOverride>>

Optional. Configuration for overriding antivirus actions per protocol.

severity_overrides: Option<Vec<SeverityOverride>>

Optional. Configuration for overriding threats actions by severity match.

threat_overrides: Option<Vec<ThreatOverride>>

Optional. Configuration for overriding threats actions by threat_id match. If a threat is matched both by configuration provided in severity_overrides and threat_overrides, the threat_overrides action is applied.