pub struct ValidationCA {
    pub certificate_provider_instance: Option<CertificateProviderInstance>,
    pub grpc_endpoint: Option<GoogleCloudNetworksecurityV1GrpcEndpoint>,
}
Specification of ValidationCA. Defines the mechanism to obtain the Certificate Authority certificate to validate the peer certificate.

This type is not used in any activity, and only used as part of another schema.

Fields

certificate_provider_instance: Option<CertificateProviderInstance>

The certificate provider instance specification that will be passed to the data plane, which will be used to load necessary credential information.

grpc_endpoint: Option<GoogleCloudNetworksecurityV1GrpcEndpoint>

gRPC specific configuration to access the gRPC server to obtain the CA certificate.