Module api

Module api 

Structs

AddAddressGroupItemsRequest
Request used by the AddAddressGroupItems method.
AddressGroup
AddressGroup is a resource that specifies how a collection of IP/DNS used in Firewall Policy.
AntivirusOverride
Defines what action to take for antivirus threats per protocol.
AuthorizationPolicy
AuthorizationPolicy is a resource that specifies how a server should authorize incoming connections. This resource in itself does not change the configuration unless it’s attached to a target https proxy or endpoint config selector resource.
AuthzPolicy
AuthzPolicy is a resource that allows to forward traffic to a callout backend designed to scan the traffic for security purposes.
AuthzPolicyAuthzRule
Conditions to match against the incoming request.
AuthzPolicyAuthzRuleFrom
Describes properties of one or more sources of a request.
AuthzPolicyAuthzRuleFromRequestSource
Describes the properties of a single source.
AuthzPolicyAuthzRuleHeaderMatch
Determines how a HTTP header should be matched.
AuthzPolicyAuthzRuleIpBlock
Represents a range of IP Addresses.
AuthzPolicyAuthzRulePrincipal
Describes the properties of a principal to be matched against.
AuthzPolicyAuthzRuleRequestResource
Describes the properties of a client VM resource accessing the internal application load balancers.
AuthzPolicyAuthzRuleRequestResourceTagValueIdSet
Describes a set of resource tag value permanent IDs to match against the resource manager tags value associated with the source VM of a request.
AuthzPolicyAuthzRuleStringMatch
Determines how a string value should be matched.
AuthzPolicyAuthzRuleTo
Describes properties of one or more targets of a request.
AuthzPolicyAuthzRuleToRequestOperation
Describes properties of one or more targets of a request.
AuthzPolicyAuthzRuleToRequestOperationHeaderSet
Describes a set of HTTP headers to match against.
AuthzPolicyCustomProvider
Allows delegating authorization decisions to Cloud IAP or to Service Extensions.
AuthzPolicyCustomProviderAuthzExtension
Optional. Delegate authorization decision to user authored extension. Only one of cloudIap or authzExtension can be specified.
AuthzPolicyCustomProviderCloudIap
Optional. Delegates authorization decisions to Cloud IAP. Applicable only for managed load balancers. Enabling Cloud IAP at the AuthzPolicy level is not compatible with Cloud IAP settings in the BackendService. Enabling IAP in both places will result in request failure. Ensure that IAP is enabled in either the AuthzPolicy or the BackendService but not in both places.
AuthzPolicyTarget
Specifies the set of targets to which this policy should be applied to.
BackendAuthenticationConfig
BackendAuthenticationConfig message groups the TrustConfig together with other settings that control how the load balancer authenticates, and expresses its identity to, the backend: * trustConfig is the attached TrustConfig. * wellKnownRoots indicates whether the load balance should trust backend server certificates that are issued by public certificate authorities, in addition to certificates trusted by the TrustConfig. * clientCertificate is a client certificate that the load balancer uses to express its identity to the backend, if the connection to the backend uses mTLS. You can attach the BackendAuthenticationConfig to the load balancer’s BackendService directly determining how that BackendService negotiates TLS.
CancelOperationRequest
The request message for Operations.CancelOperation.
CertificateProviderInstance
Specification of a TLS certificate provider instance. Workloads may have one or more CertificateProvider instances (plugins) and one of them is enabled and configured by specifying this message. Workloads use the values from this message to locate and load the CertificateProvider instance configuration.
ClientTlsPolicy
ClientTlsPolicy is a resource that specifies how a client should authenticate connections to backends of a service. This resource itself does not affect configuration unless it is attached to a backend service resource.
CloneAddressGroupItemsRequest
Request used by the CloneAddressGroupItems method.
CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action.
Destination
Specification of traffic destination attributes.
DnsThreatDetector
A DNS threat detector sends DNS query logs to a provider that then analyzes the logs to identify threat events in the DNS queries. By default, all VPC networks in your projects are included. You can exclude specific networks by supplying excluded_networks.
Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
Expr
Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: “Summary size limit” description: “Determines if a summary is less than 100 chars” expression: “document.summary.size() < 100” Example (Equality): title: “Requestor is owner” description: “Determines if requestor is the document owner” expression: “document.owner == request.auth.claims.email” Example (Logic): title: “Public documents” description: “Determine whether the document should be publicly visible” expression: “document.type != ‘private’ && document.type != ‘internal’” Example (Data Manipulation): title: “Notification string” description: “Create a notification string with a timestamp.” expression: “’New message received at ’ + string(document.create_time)” The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
FirewallEndpoint
Message describing Endpoint object.
FirewallEndpointAssociation
Message describing Association object
FirewallEndpointAssociationReference
This is a subset of the FirewallEndpointAssociation message, containing fields to be used by the consumer.
FirewallEndpointEndpointSettings
Settings for the endpoint.
GatewaySecurityPolicy
The GatewaySecurityPolicy resource contains a collection of GatewaySecurityPolicyRules and associated metadata.
GatewaySecurityPolicyRule
The GatewaySecurityPolicyRule resource is in a nested collection within a GatewaySecurityPolicy and represents a traffic matching condition and associated action to perform.
GoogleCloudNetworksecurityV1CertificateProvider
Specification of certificate provider. Defines the mechanism to obtain the certificate and private key for peer to peer authentication.
GoogleCloudNetworksecurityV1GrpcEndpoint
Specification of the GRPC Endpoint.
GoogleIamV1AuditConfig
Specifies the audit configuration for a service. The configuration determines which permission types are logged, and what identities, if any, are exempted from logging. An AuditConfig must have one or more AuditLogConfigs. If there are AuditConfigs for both allServices and a specific service, the union of the two AuditConfigs is used for that service: the log_types specified in each AuditConfig are enabled, and the exempted_members in each AuditLogConfig are exempted. Example Policy with multiple AuditConfigs: { “audit_configs”: [ { “service”: “allServices”, “audit_log_configs”: [ { “log_type”: “DATA_READ”, “exempted_members”: [ “user:jose@example.com” ] }, { “log_type”: “DATA_WRITE” }, { “log_type”: “ADMIN_READ” } ] }, { “service”: “sampleservice.googleapis.com”, “audit_log_configs”: [ { “log_type”: “DATA_READ” }, { “log_type”: “DATA_WRITE”, “exempted_members”: [ “user:aliya@example.com” ] } ] } ] } For sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also exempts jose@example.com from DATA_READ logging, and aliya@example.com from DATA_WRITE logging.
GoogleIamV1AuditLogConfig
Provides the configuration for logging a type of permissions. Example: { “audit_log_configs”: [ { “log_type”: “DATA_READ”, “exempted_members”: [ “user:jose@example.com” ] }, { “log_type”: “DATA_WRITE” } ] } This enables ‘DATA_READ’ and ‘DATA_WRITE’ logging, while exempting jose@example.com from DATA_READ logging.
GoogleIamV1Binding
Associates members, or principals, with a role.
GoogleIamV1Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A Policy is a collection of bindings. A binding binds one or more members, or principals, to a single role. Principals can be user accounts, service accounts, Google groups, and domains (such as G Suite). A role is a named list of permissions; each role can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a binding can also specify a condition, which is a logical expression that allows access to a resource only if the expression evaluates to true. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the IAM documentation. JSON example: { "bindings": [ { "role": "roles/resourcemanager.organizationAdmin", "members": [ "user:mike@example.com", "group:admins@example.com", "domain:google.com", "serviceAccount:my-project-id@appspot.gserviceaccount.com" ] }, { "role": "roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com" ], "condition": { "title": "expirable access", "description": "Does not grant access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')", } } ], "etag": "BwWWja0YfJA=", "version": 3 } YAML example: bindings: - members: - user:mike@example.com - group:admins@example.com - domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For a description of IAM and its features, see the IAM documentation.
GoogleIamV1SetIamPolicyRequest
Request message for SetIamPolicy method.
GoogleIamV1TestIamPermissionsRequest
Request message for TestIamPermissions method.
GoogleIamV1TestIamPermissionsResponse
Response message for TestIamPermissions method.
HttpHeaderMatch
Specification of HTTP header match attributes.
InterceptDeployment
A deployment represents a zonal intercept backend ready to accept GENEVE-encapsulated traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global intercept service.
InterceptDeploymentGroup
A deployment group aggregates many zonal intercept backends (deployments) into a single global intercept service. Consumers can connect this service using an endpoint group.
InterceptDeploymentGroupConnectedEndpointGroup
An endpoint group connected to this deployment group.
InterceptDeploymentGroupDeployment
A deployment belonging to this deployment group.
InterceptEndpointGroup
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure intercept for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A firewall rule that references the security profile (group).
InterceptEndpointGroupAssociation
An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable intercept by itself. To enable intercept, the user must also create a network firewall policy containing intercept rules and associate it with the network.
InterceptEndpointGroupAssociationDetails
The endpoint group’s view of a connected association.
InterceptEndpointGroupAssociationLocationDetails
Contains details about the state of an association in a specific cloud location.
InterceptEndpointGroupConnectedDeploymentGroup
The endpoint group’s view of a connected deployment group.
InterceptLocation
Details about intercept in a specific cloud location.
ListAddressGroupReferencesResponse
Response of the ListAddressGroupReferences method.
ListAddressGroupReferencesResponseAddressGroupReference
The Reference of AddressGroup.
ListAddressGroupsResponse
Response returned by the ListAddressGroups method.
ListAuthorizationPoliciesResponse
Response returned by the ListAuthorizationPolicies method.
ListAuthzPoliciesResponse
Message for response to listing AuthzPolicy resources.
ListBackendAuthenticationConfigsResponse
Response returned by the ListBackendAuthenticationConfigs method.
ListClientTlsPoliciesResponse
Response returned by the ListClientTlsPolicies method.
ListDnsThreatDetectorsResponse
The response message to requesting a list of DnsThreatDetectors.
ListFirewallEndpointAssociationsResponse
Message for response to listing Associations
ListFirewallEndpointsResponse
Message for response to listing Endpoints
ListGatewaySecurityPoliciesResponse
Response returned by the ListGatewaySecurityPolicies method.
ListGatewaySecurityPolicyRulesResponse
Response returned by the ListGatewaySecurityPolicyRules method.
ListInterceptDeploymentGroupsResponse
Response message for ListInterceptDeploymentGroups.
ListInterceptDeploymentsResponse
Response message for ListInterceptDeployments.
ListInterceptEndpointGroupAssociationsResponse
Response message for ListInterceptEndpointGroupAssociations.
ListInterceptEndpointGroupsResponse
Response message for ListInterceptEndpointGroups.
ListLocationsResponse
The response message for Locations.ListLocations.
ListMirroringDeploymentGroupsResponse
Response message for ListMirroringDeploymentGroups.
ListMirroringDeploymentsResponse
Response message for ListMirroringDeployments.
ListMirroringEndpointGroupAssociationsResponse
Response message for ListMirroringEndpointGroupAssociations.
ListMirroringEndpointGroupsResponse
Response message for ListMirroringEndpointGroups.
ListOperationsResponse
The response message for Operations.ListOperations.
ListSecurityProfileGroupsResponse
Response returned by the ListSecurityProfileGroups method.
ListSecurityProfilesResponse
Response returned by the ListSecurityProfiles method.
ListServerTlsPoliciesResponse
Response returned by the ListServerTlsPolicies method.
ListTlsInspectionPoliciesResponse
Response returned by the ListTlsInspectionPolicies method.
ListUrlListsResponse
Response returned by the ListUrlLists method.
Location
A resource that represents a Google Cloud location.
MTLSPolicy
Specification of the MTLSPolicy.
MirroringDeployment
A deployment represents a zonal mirroring backend ready to accept GENEVE-encapsulated replica traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global mirroring service.
MirroringDeploymentGroup
A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.
MirroringDeploymentGroupConnectedEndpointGroup
An endpoint group connected to this deployment group.
MirroringDeploymentGroupDeployment
A deployment belonging to this deployment group.
MirroringEndpointGroup
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A mirroring rule that references the security profile (group).
MirroringEndpointGroupAssociation
An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable mirroring by itself. To enable mirroring, the user must also create a network firewall policy containing mirroring rules and associate it with the network.
MirroringEndpointGroupAssociationDetails
The endpoint group’s view of a connected association.
MirroringEndpointGroupAssociationLocationDetails
Contains details about the state of an association in a specific cloud location.
MirroringEndpointGroupConnectedDeploymentGroup
The endpoint group’s view of a connected deployment group.
MirroringLocation
Details about mirroring in a specific cloud location.
NetworkSecurity
Central instance to access all NetworkSecurity related resource activities
Operation
This resource represents a long-running operation that is the result of a network API call.
OrganizationLocationAddressGroupAddItemCall
Adds items to an address group.
OrganizationLocationAddressGroupCloneItemCall
Clones items from one address group to another.
OrganizationLocationAddressGroupCreateCall
Creates a new address group in a given project and location.
OrganizationLocationAddressGroupDeleteCall
Deletes an address group.
OrganizationLocationAddressGroupGetCall
Gets details of a single address group.
OrganizationLocationAddressGroupListCall
Lists address groups in a given project and location.
OrganizationLocationAddressGroupListReferenceCall
Lists references of an address group.
OrganizationLocationAddressGroupPatchCall
Updates parameters of an address group.
OrganizationLocationAddressGroupRemoveItemCall
Removes items from an address group.
OrganizationLocationFirewallEndpointCreateCall
Creates a new FirewallEndpoint in a given project and location.
OrganizationLocationFirewallEndpointDeleteCall
Deletes a single Endpoint.
OrganizationLocationFirewallEndpointGetCall
Gets details of a single Endpoint.
OrganizationLocationFirewallEndpointListCall
Lists FirewallEndpoints in a given project and location.
OrganizationLocationFirewallEndpointPatchCall
Update a single Endpoint.
OrganizationLocationOperationCancelCall
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
OrganizationLocationOperationDeleteCall
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED.
OrganizationLocationOperationGetCall
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
OrganizationLocationOperationListCall
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
OrganizationLocationSecurityProfileCreateCall
Creates a new SecurityProfile in a given organization and location.
OrganizationLocationSecurityProfileDeleteCall
Deletes a single SecurityProfile.
OrganizationLocationSecurityProfileGetCall
Gets details of a single SecurityProfile.
OrganizationLocationSecurityProfileGroupCreateCall
Creates a new SecurityProfileGroup in a given organization and location.
OrganizationLocationSecurityProfileGroupDeleteCall
Deletes a single SecurityProfileGroup.
OrganizationLocationSecurityProfileGroupGetCall
Gets details of a single SecurityProfileGroup.
OrganizationLocationSecurityProfileGroupListCall
Lists SecurityProfileGroups in a given organization and location.
OrganizationLocationSecurityProfileGroupPatchCall
Updates the parameters of a single SecurityProfileGroup.
OrganizationLocationSecurityProfileListCall
Lists SecurityProfiles in a given organization and location.
OrganizationLocationSecurityProfilePatchCall
Updates the parameters of a single SecurityProfile.
OrganizationMethods
A builder providing access to all methods supported on organization resources. It is not used directly, but through the NetworkSecurity hub.
ProjectLocationAddressGroupAddItemCall
Adds items to an address group.
ProjectLocationAddressGroupCloneItemCall
Clones items from one address group to another.
ProjectLocationAddressGroupCreateCall
Creates a new address group in a given project and location.
ProjectLocationAddressGroupDeleteCall
Deletes a single address group.
ProjectLocationAddressGroupGetCall
Gets details of a single address group.
ProjectLocationAddressGroupGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationAddressGroupListCall
Lists address groups in a given project and location.
ProjectLocationAddressGroupListReferenceCall
Lists references of an address group.
ProjectLocationAddressGroupPatchCall
Updates the parameters of a single address group.
ProjectLocationAddressGroupRemoveItemCall
Removes items from an address group.
ProjectLocationAddressGroupSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationAddressGroupTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationAuthorizationPolicyCreateCall
Creates a new AuthorizationPolicy in a given project and location.
ProjectLocationAuthorizationPolicyDeleteCall
Deletes a single AuthorizationPolicy.
ProjectLocationAuthorizationPolicyGetCall
Gets details of a single AuthorizationPolicy.
ProjectLocationAuthorizationPolicyGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationAuthorizationPolicyListCall
Lists AuthorizationPolicies in a given project and location.
ProjectLocationAuthorizationPolicyPatchCall
Updates the parameters of a single AuthorizationPolicy.
ProjectLocationAuthorizationPolicySetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationAuthorizationPolicyTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationAuthzPolicyCreateCall
Creates a new AuthzPolicy in a given project and location.
ProjectLocationAuthzPolicyDeleteCall
Deletes a single AuthzPolicy.
ProjectLocationAuthzPolicyGetCall
Gets details of a single AuthzPolicy.
ProjectLocationAuthzPolicyGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationAuthzPolicyListCall
Lists AuthzPolicies in a given project and location.
ProjectLocationAuthzPolicyPatchCall
Updates the parameters of a single AuthzPolicy.
ProjectLocationAuthzPolicySetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationAuthzPolicyTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationBackendAuthenticationConfigCreateCall
Creates a new BackendAuthenticationConfig in a given project and location.
ProjectLocationBackendAuthenticationConfigDeleteCall
Deletes a single BackendAuthenticationConfig to BackendAuthenticationConfig.
ProjectLocationBackendAuthenticationConfigGetCall
Gets details of a single BackendAuthenticationConfig to BackendAuthenticationConfig.
ProjectLocationBackendAuthenticationConfigListCall
Lists BackendAuthenticationConfigs in a given project and location.
ProjectLocationBackendAuthenticationConfigPatchCall
Updates the parameters of a single BackendAuthenticationConfig to BackendAuthenticationConfig.
ProjectLocationClientTlsPolicyCreateCall
Creates a new ClientTlsPolicy in a given project and location.
ProjectLocationClientTlsPolicyDeleteCall
Deletes a single ClientTlsPolicy.
ProjectLocationClientTlsPolicyGetCall
Gets details of a single ClientTlsPolicy.
ProjectLocationClientTlsPolicyGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationClientTlsPolicyListCall
Lists ClientTlsPolicies in a given project and location.
ProjectLocationClientTlsPolicyPatchCall
Updates the parameters of a single ClientTlsPolicy.
ProjectLocationClientTlsPolicySetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationClientTlsPolicyTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationDnsThreatDetectorCreateCall
Creates a new DnsThreatDetector in a given project and location.
ProjectLocationDnsThreatDetectorDeleteCall
Deletes a single DnsThreatDetector.
ProjectLocationDnsThreatDetectorGetCall
Gets the details of a single DnsThreatDetector.
ProjectLocationDnsThreatDetectorListCall
Lists DnsThreatDetectors in a given project and location.
ProjectLocationDnsThreatDetectorPatchCall
Updates a single DnsThreatDetector.
ProjectLocationFirewallEndpointAssociationCreateCall
Creates a new FirewallEndpointAssociation in a given project and location.
ProjectLocationFirewallEndpointAssociationDeleteCall
Deletes a single FirewallEndpointAssociation.
ProjectLocationFirewallEndpointAssociationGetCall
Gets details of a single FirewallEndpointAssociation.
ProjectLocationFirewallEndpointAssociationListCall
Lists Associations in a given project and location.
ProjectLocationFirewallEndpointAssociationPatchCall
Update a single FirewallEndpointAssociation.
ProjectLocationFirewallEndpointCreateCall
Creates a new FirewallEndpoint in a given project and location.
ProjectLocationFirewallEndpointDeleteCall
Deletes a single Endpoint.
ProjectLocationFirewallEndpointGetCall
Gets details of a single Endpoint.
ProjectLocationFirewallEndpointListCall
Lists FirewallEndpoints in a given project and location.
ProjectLocationFirewallEndpointPatchCall
Update a single Endpoint.
ProjectLocationGatewaySecurityPolicyCreateCall
Creates a new GatewaySecurityPolicy in a given project and location.
ProjectLocationGatewaySecurityPolicyDeleteCall
Deletes a single GatewaySecurityPolicy.
ProjectLocationGatewaySecurityPolicyGetCall
Gets details of a single GatewaySecurityPolicy.
ProjectLocationGatewaySecurityPolicyListCall
Lists GatewaySecurityPolicies in a given project and location.
ProjectLocationGatewaySecurityPolicyPatchCall
Updates the parameters of a single GatewaySecurityPolicy.
ProjectLocationGatewaySecurityPolicyRuleCreateCall
Creates a new GatewaySecurityPolicy in a given project and location.
ProjectLocationGatewaySecurityPolicyRuleDeleteCall
Deletes a single GatewaySecurityPolicyRule.
ProjectLocationGatewaySecurityPolicyRuleGetCall
Gets details of a single GatewaySecurityPolicyRule.
ProjectLocationGatewaySecurityPolicyRuleListCall
Lists GatewaySecurityPolicyRules in a given project and location.
ProjectLocationGatewaySecurityPolicyRulePatchCall
Updates the parameters of a single GatewaySecurityPolicyRule.
ProjectLocationGetCall
Gets information about a location.
ProjectLocationInterceptDeploymentCreateCall
Creates a deployment in a given project and location. See https://google.aip.dev/133.
ProjectLocationInterceptDeploymentDeleteCall
Deletes a deployment. See https://google.aip.dev/135.
ProjectLocationInterceptDeploymentGetCall
Gets a specific deployment. See https://google.aip.dev/131.
ProjectLocationInterceptDeploymentGroupCreateCall
Creates a deployment group in a given project and location. See https://google.aip.dev/133.
ProjectLocationInterceptDeploymentGroupDeleteCall
Deletes a deployment group. See https://google.aip.dev/135.
ProjectLocationInterceptDeploymentGroupGetCall
Gets a specific deployment group. See https://google.aip.dev/131.
ProjectLocationInterceptDeploymentGroupListCall
Lists deployment groups in a given project and location. See https://google.aip.dev/132.
ProjectLocationInterceptDeploymentGroupPatchCall
Updates a deployment group. See https://google.aip.dev/134.
ProjectLocationInterceptDeploymentListCall
Lists deployments in a given project and location. See https://google.aip.dev/132.
ProjectLocationInterceptDeploymentPatchCall
Updates a deployment. See https://google.aip.dev/134.
ProjectLocationInterceptEndpointGroupAssociationCreateCall
Creates an association in a given project and location. See https://google.aip.dev/133.
ProjectLocationInterceptEndpointGroupAssociationDeleteCall
Deletes an association. See https://google.aip.dev/135.
ProjectLocationInterceptEndpointGroupAssociationGetCall
Gets a specific association. See https://google.aip.dev/131.
ProjectLocationInterceptEndpointGroupAssociationListCall
Lists associations in a given project and location. See https://google.aip.dev/132.
ProjectLocationInterceptEndpointGroupAssociationPatchCall
Updates an association. See https://google.aip.dev/134.
ProjectLocationInterceptEndpointGroupCreateCall
Creates an endpoint group in a given project and location. See https://google.aip.dev/133.
ProjectLocationInterceptEndpointGroupDeleteCall
Deletes an endpoint group. See https://google.aip.dev/135.
ProjectLocationInterceptEndpointGroupGetCall
Gets a specific endpoint group. See https://google.aip.dev/131.
ProjectLocationInterceptEndpointGroupListCall
Lists endpoint groups in a given project and location. See https://google.aip.dev/132.
ProjectLocationInterceptEndpointGroupPatchCall
Updates an endpoint group. See https://google.aip.dev/134.
ProjectLocationListCall
Lists information about the supported locations for this service.
ProjectLocationMirroringDeploymentCreateCall
Creates a deployment in a given project and location. See https://google.aip.dev/133.
ProjectLocationMirroringDeploymentDeleteCall
Deletes a deployment. See https://google.aip.dev/135.
ProjectLocationMirroringDeploymentGetCall
Gets a specific deployment. See https://google.aip.dev/131.
ProjectLocationMirroringDeploymentGroupCreateCall
Creates a deployment group in a given project and location. See https://google.aip.dev/133.
ProjectLocationMirroringDeploymentGroupDeleteCall
Deletes a deployment group. See https://google.aip.dev/135.
ProjectLocationMirroringDeploymentGroupGetCall
Gets a specific deployment group. See https://google.aip.dev/131.
ProjectLocationMirroringDeploymentGroupListCall
Lists deployment groups in a given project and location. See https://google.aip.dev/132.
ProjectLocationMirroringDeploymentGroupPatchCall
Updates a deployment group. See https://google.aip.dev/134.
ProjectLocationMirroringDeploymentListCall
Lists deployments in a given project and location. See https://google.aip.dev/132.
ProjectLocationMirroringDeploymentPatchCall
Updates a deployment. See https://google.aip.dev/134.
ProjectLocationMirroringEndpointGroupAssociationCreateCall
Creates an association in a given project and location. See https://google.aip.dev/133.
ProjectLocationMirroringEndpointGroupAssociationDeleteCall
Deletes an association. See https://google.aip.dev/135.
ProjectLocationMirroringEndpointGroupAssociationGetCall
Gets a specific association. See https://google.aip.dev/131.
ProjectLocationMirroringEndpointGroupAssociationListCall
Lists associations in a given project and location. See https://google.aip.dev/132.
ProjectLocationMirroringEndpointGroupAssociationPatchCall
Updates an association. See https://google.aip.dev/134.
ProjectLocationMirroringEndpointGroupCreateCall
Creates an endpoint group in a given project and location. See https://google.aip.dev/133.
ProjectLocationMirroringEndpointGroupDeleteCall
Deletes an endpoint group. See https://google.aip.dev/135.
ProjectLocationMirroringEndpointGroupGetCall
Gets a specific endpoint group. See https://google.aip.dev/131.
ProjectLocationMirroringEndpointGroupListCall
Lists endpoint groups in a given project and location. See https://google.aip.dev/132.
ProjectLocationMirroringEndpointGroupPatchCall
Updates an endpoint group. See https://google.aip.dev/134.
ProjectLocationOperationCancelCall
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
ProjectLocationOperationDeleteCall
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED.
ProjectLocationOperationGetCall
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
ProjectLocationOperationListCall
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
ProjectLocationServerTlsPolicyCreateCall
Creates a new ServerTlsPolicy in a given project and location.
ProjectLocationServerTlsPolicyDeleteCall
Deletes a single ServerTlsPolicy.
ProjectLocationServerTlsPolicyGetCall
Gets details of a single ServerTlsPolicy.
ProjectLocationServerTlsPolicyGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationServerTlsPolicyListCall
Lists ServerTlsPolicies in a given project and location.
ProjectLocationServerTlsPolicyPatchCall
Updates the parameters of a single ServerTlsPolicy.
ProjectLocationServerTlsPolicySetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationServerTlsPolicyTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationTlsInspectionPolicyCreateCall
Creates a new TlsInspectionPolicy in a given project and location.
ProjectLocationTlsInspectionPolicyDeleteCall
Deletes a single TlsInspectionPolicy.
ProjectLocationTlsInspectionPolicyGetCall
Gets details of a single TlsInspectionPolicy.
ProjectLocationTlsInspectionPolicyListCall
Lists TlsInspectionPolicies in a given project and location.
ProjectLocationTlsInspectionPolicyPatchCall
Updates the parameters of a single TlsInspectionPolicy.
ProjectLocationUrlListCreateCall
Creates a new UrlList in a given project and location.
ProjectLocationUrlListDeleteCall
Deletes a single UrlList.
ProjectLocationUrlListGetCall
Gets details of a single UrlList.
ProjectLocationUrlListListCall
Lists UrlLists in a given project and location.
ProjectLocationUrlListPatchCall
Updates the parameters of a single UrlList.
ProjectMethods
A builder providing access to all methods supported on project resources. It is not used directly, but through the NetworkSecurity hub.
RemoveAddressGroupItemsRequest
Request used by the RemoveAddressGroupItems method.
Rule
Specification of rules.
SecurityProfile
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
SecurityProfileGroup
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
ServerTlsPolicy
ServerTlsPolicy is a resource that specifies how a server should authenticate incoming requests. This resource itself does not affect configuration unless it is attached to a target HTTPS proxy or endpoint config selector resource. ServerTlsPolicy in the form accepted by Application Load Balancers can be attached only to TargetHttpsProxy with an EXTERNAL, EXTERNAL_MANAGED or INTERNAL_MANAGED load balancing scheme. Traffic Director compatible ServerTlsPolicies can be attached to EndpointPolicy and TargetHttpsProxy with Traffic Director INTERNAL_SELF_MANAGED load balancing scheme.
SeverityOverride
Defines what action to take for a specific severity match.
Specification of traffic source attributes.
Status
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
ThreatOverride
Defines what action to take for a specific threat_id match.
ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
TlsInspectionPolicy
The TlsInspectionPolicy resource contains references to CA pools in Certificate Authority Service and associated metadata.
UrlList
UrlList proto helps users to set reusable, independently manageable lists of hosts, host patterns, URLs, URL patterns.
ValidationCA
Specification of ValidationCA. Defines the mechanism to obtain the Certificate Authority certificate to validate the peer certificate.

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.