pub struct AuthzPolicyAuthzRuleFromRequestSource {
pub ip_blocks: Option<Vec<AuthzPolicyAuthzRuleIpBlock>>,
pub principals: Option<Vec<AuthzPolicyAuthzRulePrincipal>>,
pub resources: Option<Vec<AuthzPolicyAuthzRuleRequestResource>>,
}Expand description
Describes the properties of a single source.
This type is not used in any activity, and only used as part of another schema.
Fields
ip_blocks: Option<Vec<AuthzPolicyAuthzRuleIpBlock>>Optional. A list of IP addresses or IP address ranges to match against the source IP address of the request. Limited to 10 ip_blocks per Authorization Policy
principals: Option<Vec<AuthzPolicyAuthzRulePrincipal>>Optional. A list of identities derived from the client’s certificate. This field will not match on a request unless frontend mutual TLS is enabled for the forwarding rule or Gateway and the client certificate has been successfully validated by mTLS. Each identity is a string whose value is matched against a list of URI SANs, DNS Name SANs, or the common name in the client’s certificate. A match happens when any principal matches with the rule. Limited to 50 principals per Authorization Policy for regional internal Application Load Balancers, regional external Application Load Balancers, cross-region internal Application Load Balancers, and Cloud Service Mesh. This field is not supported for global external Application Load Balancers.
resources: Option<Vec<AuthzPolicyAuthzRuleRequestResource>>Optional. A list of resources to match against the resource of the source VM of a request. Limited to 10 resources per Authorization Policy.