pub struct AuthzPolicyAuthzRuleToRequestOperation {
pub header_set: Option<AuthzPolicyAuthzRuleToRequestOperationHeaderSet>,
pub hosts: Option<Vec<AuthzPolicyAuthzRuleStringMatch>>,
pub methods: Option<Vec<String>>,
pub paths: Option<Vec<AuthzPolicyAuthzRuleStringMatch>>,
}Expand description
Describes properties of one or more targets of a request.
This type is not used in any activity, and only used as part of another schema.
Fields
header_set: Option<AuthzPolicyAuthzRuleToRequestOperationHeaderSet>Optional. A list of headers to match against in http header.
hosts: Option<Vec<AuthzPolicyAuthzRuleStringMatch>>Optional. A list of HTTP Hosts to match against. The match can be one of exact, prefix, suffix, or contains (substring match). Matches are always case sensitive unless the ignoreCase is set. Limited to 10 hosts per Authorization Policy.
methods: Option<Vec<String>>Optional. A list of HTTP methods to match against. Each entry must be a valid HTTP method name (GET, PUT, POST, HEAD, PATCH, DELETE, OPTIONS). It only allows exact match and is always case sensitive. Limited to 10 methods per Authorization Policy.
paths: Option<Vec<AuthzPolicyAuthzRuleStringMatch>>Optional. A list of paths to match against. The match can be one of exact, prefix, suffix, or contains (substring match). Matches are always case sensitive unless the ignoreCase is set. Limited to 10 paths per Authorization Policy. Note that this path match includes the query parameters. For gRPC services, this should be a fully-qualified name of the form /package.service/method.