pub struct AuthzPolicyTarget {
pub load_balancing_scheme: Option<String>,
pub resources: Option<Vec<String>>,
}Expand description
Specifies the set of targets to which this policy should be applied to.
This type is not used in any activity, and only used as part of another schema.
Fields
load_balancing_scheme: Option<String>Required. All gateways and forwarding rules referenced by this policy and extensions must share the same load balancing scheme. Supported values: INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer to Backend services overview.
resources: Option<Vec<String>>Required. A list of references to the Forwarding Rules on which this policy will be applied.