pub struct ClientTlsPolicy {
pub client_certificate: Option<GoogleCloudNetworksecurityV1CertificateProvider>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub server_validation_ca: Option<Vec<ValidationCA>>,
pub sni: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
ClientTlsPolicy is a resource that specifies how a client should authenticate connections to backends of a service. This resource itself does not affect configuration unless it is attached to a backend service resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations client tls policies create projects (request)
- locations client tls policies get projects (response)
- locations client tls policies patch projects (request)
Fields
client_certificate: Option<GoogleCloudNetworksecurityV1CertificateProvider>Optional. Defines a mechanism to provision client identity (public and private keys) for peer to peer authentication. The presence of this dictates mTLS.
create_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was created.
description: Option<String>Optional. Free-text description of the resource.
labels: Option<HashMap<String, String>>Optional. Set of label tags associated with the resource.
name: Option<String>Required. Name of the ClientTlsPolicy resource. It matches the pattern projects/{project}/locations/{location}/clientTlsPolicies/{client_tls_policy}
server_validation_ca: Option<Vec<ValidationCA>>Optional. Defines the mechanism to obtain the Certificate Authority certificate to validate the server certificate. If empty, client does not validate the server certificate.
sni: Option<String>Optional. Server Name Indication string to present to the server during TLS handshake. E.g: “secure.example.com”.
update_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was updated.