pub struct Destination {
pub hosts: Option<Vec<String>>,
pub http_header_match: Option<HttpHeaderMatch>,
pub methods: Option<Vec<String>>,
pub ports: Option<Vec<u32>>,
}Expand description
Specification of traffic destination attributes.
This type is not used in any activity, and only used as part of another schema.
Fields
hosts: Option<Vec<String>>Required. List of host names to match. Matched against the “:authority” header in http requests. At least one host should match. Each host can be an exact match, or a prefix match (example “mydomain.”) or a suffix match (example “.myorg.com”) or a presence (any) match “*”.
http_header_match: Option<HttpHeaderMatch>Optional. Match against key:value pair in http header. Provides a flexible match based on HTTP headers, for potentially advanced use cases. At least one header should match. Avoid using header matches to make authorization decisions unless there is a strong guarantee that requests arrive through a trusted client or proxy.
methods: Option<Vec<String>>Optional. A list of HTTP methods to match. At least one method should match. Should not be set for gRPC services.
ports: Option<Vec<u32>>Required. List of destination ports to match. At least one port should match.