pub struct DnsThreatDetector {
pub create_time: Option<DateTime<Utc>>,
pub excluded_networks: Option<Vec<String>>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub provider: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A DNS threat detector sends DNS query logs to a provider that then analyzes the logs to identify threat events in the DNS queries. By default, all VPC networks in your projects are included. You can exclude specific networks by supplying excluded_networks.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations dns threat detectors create projects (request|response)
- locations dns threat detectors get projects (response)
- locations dns threat detectors patch projects (request|response)
Fields
create_time: Option<DateTime<Utc>>Output only. Create time stamp.
excluded_networks: Option<Vec<String>>Optional. A list of network resource names which aren’t monitored by this DnsThreatDetector. Example: projects/PROJECT_ID/global/networks/NETWORK_NAME.
labels: Option<HashMap<String, String>>Optional. Any labels associated with the DnsThreatDetector, listed as key value pairs.
name: Option<String>Immutable. Identifier. Name of the DnsThreatDetector resource.
provider: Option<String>Required. The provider used for DNS threat analysis.
update_time: Option<DateTime<Utc>>Output only. Update time stamp.