pub struct InterceptDeployment {
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub forwarding_rule: Option<String>,
pub intercept_deployment_group: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub reconciling: Option<bool>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A deployment represents a zonal intercept backend ready to accept GENEVE-encapsulated traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global intercept service.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
create_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.
description: Option<String>Optional. User-provided description of the deployment. Used as additional context for the deployment.
forwarding_rule: Option<String>Required. Immutable. The regional forwarding rule that fronts the interceptors, for example: projects/123456789/regions/us-central1/forwardingRules/my-rule. See https://google.aip.dev/124.
intercept_deployment_group: Option<String>Required. Immutable. The deployment group that this deployment is a part of, for example: projects/123456789/locations/global/interceptDeploymentGroups/my-dg. See https://google.aip.dev/124.
labels: Option<HashMap<String, String>>Optional. Labels are key/value pairs that help to organize and filter resources.
name: Option<String>Immutable. Identifier. The resource name of this deployment, for example: projects/123456789/locations/us-central1-a/interceptDeployments/my-dep. See https://google.aip.dev/122 for more details.
reconciling: Option<bool>Output only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This part of the normal operation (e.g. linking a new association to the parent group). See https://google.aip.dev/128.
state: Option<String>Output only. The current state of the deployment. See https://google.aip.dev/216.
update_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.