pub struct MTLSPolicy {
pub client_validation_ca: Option<Vec<ValidationCA>>,
pub client_validation_mode: Option<String>,
pub client_validation_trust_config: Option<String>,
}Expand description
Specification of the MTLSPolicy.
This type is not used in any activity, and only used as part of another schema.
Fields
client_validation_ca: Option<Vec<ValidationCA>>Required if the policy is to be used with Traffic Director. For Application Load Balancers it must be empty. Defines the mechanism to obtain the Certificate Authority certificate to validate the client certificate.
client_validation_mode: Option<String>When the client presents an invalid certificate or no certificate to the load balancer, the client_validation_mode specifies how the client connection is handled. Required if the policy is to be used with the Application Load Balancers. For Traffic Director it must be empty.
client_validation_trust_config: Option<String>Reference to the TrustConfig from certificatemanager.googleapis.com namespace. If specified, the chain validation will be performed against certificates configured in the given TrustConfig. Allowed only if the policy is to be used with Application Load Balancers.