pub struct MirroringEndpointGroup {
pub associations: Option<Vec<MirroringEndpointGroupAssociationDetails>>,
pub connected_deployment_groups: Option<Vec<MirroringEndpointGroupConnectedDeploymentGroup>>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub mirroring_deployment_group: Option<String>,
pub name: Option<String>,
pub reconciling: Option<bool>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A mirroring rule that references the security profile (group).
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
associations: Option<Vec<MirroringEndpointGroupAssociationDetails>>Output only. List of associations to this endpoint group.
connected_deployment_groups: Option<Vec<MirroringEndpointGroupConnectedDeploymentGroup>>Output only. List of details about the connected deployment groups to this endpoint group.
create_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was created. See https://google.aip.dev/148#timestamps.
description: Option<String>Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group.
labels: Option<HashMap<String, String>>Optional. Labels are key/value pairs that help to organize and filter resources.
mirroring_deployment_group: Option<String>Immutable. The deployment group that this DIRECT endpoint group is connected to, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.
name: Option<String>Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https://google.aip.dev/122 for more details.
reconciling: Option<bool>Output only. The current state of the resource does not match the user’s intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https://google.aip.dev/128.
state: Option<String>Output only. The current state of the endpoint group. See https://google.aip.dev/216.
update_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps.