pub struct ServerTlsPolicy {
pub allow_open: Option<bool>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub mtls_policy: Option<MTLSPolicy>,
pub name: Option<String>,
pub server_certificate: Option<GoogleCloudNetworksecurityV1CertificateProvider>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
ServerTlsPolicy is a resource that specifies how a server should authenticate incoming requests. This resource itself does not affect configuration unless it is attached to a target HTTPS proxy or endpoint config selector resource. ServerTlsPolicy in the form accepted by Application Load Balancers can be attached only to TargetHttpsProxy with an EXTERNAL, EXTERNAL_MANAGED or INTERNAL_MANAGED load balancing scheme. Traffic Director compatible ServerTlsPolicies can be attached to EndpointPolicy and TargetHttpsProxy with Traffic Director INTERNAL_SELF_MANAGED load balancing scheme.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations server tls policies create projects (request)
- locations server tls policies get projects (response)
- locations server tls policies patch projects (request)
Fields
allow_open: Option<bool>This field applies only for Traffic Director policies. It is must be set to false for Application Load Balancer policies. Determines if server allows plaintext connections. If set to true, server allows plain text connections. By default, it is set to false. This setting is not exclusive of other encryption modes. For example, if allow_open and mtls_policy are set, server allows both plain text and mTLS connections. See documentation of other encryption modes to confirm compatibility. Consider using it if you wish to upgrade in place your deployment to TLS while having mixed TLS and non-TLS traffic reaching port :80.
create_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was created.
description: Option<String>Free-text description of the resource.
labels: Option<HashMap<String, String>>Set of label tags associated with the resource.
mtls_policy: Option<MTLSPolicy>This field is required if the policy is used with Application Load Balancers. This field can be empty for Traffic Director. Defines a mechanism to provision peer validation certificates for peer to peer authentication (Mutual TLS - mTLS). If not specified, client certificate will not be requested. The connection is treated as TLS and not mTLS. If allow_open and mtls_policy are set, server allows both plain text and mTLS connections.
name: Option<String>Required. Name of the ServerTlsPolicy resource. It matches the pattern projects/*/locations/{location}/serverTlsPolicies/{server_tls_policy}
server_certificate: Option<GoogleCloudNetworksecurityV1CertificateProvider>Optional if policy is to be used with Traffic Director. For Application Load Balancers must be empty. Defines a mechanism to provision server identity (public and private keys). Cannot be combined with allow_open as a permissive mode that allows both plain text and TLS is not supported.
update_time: Option<DateTime<Utc>>Output only. The timestamp when the resource was updated.